@@ -11,7 +11,6 @@ from pathlib import Path
 from typing import (
     Any,
     AsyncContextManager,
-    Iterable,
     List,
     Mapping,
     MutableMapping,
@@ -26,7 +25,6 @@ from typing import (
 from uuid import UUID
 
 import aiodocker
-import netifaces
 import trafaret as t
 from aiodocker.docker import DockerContainer
 from typing_extensions import Final
@@ -325,16 +323,3 @@ async def host_pid_to_container_pid(container_id: str, host_pid: HostPID) -> Con
 async def container_pid_to_host_pid(container_id: str, container_pid: ContainerPID) -> HostPID:
     # TODO: implement
     return NotHostPID
-
-
-def fetch_local_ipaddrs(cidr: IPNetwork) -> Iterable[IPAddress]:
-    ifnames = netifaces.interfaces()
-    proto = netifaces.AF_INET if cidr.version == 4 else netifaces.AF_INET6
-    for ifname in ifnames:
-        addrs = netifaces.ifaddresses(ifname).get(proto, None)
-        if addrs is None:
-            continue
-        for entry in addrs:
-            addr = ipaddress.ip_address(entry["addr"])
-            if addr in cidr:
-                yield addr
